package com.ynet.life.log;

import com.ynet.gene.accesscontrol.GENEAccessController;
import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEConstance;
import com.ynet.gene.core.GENEException;
import com.ynet.gene.data.DataElement;
import com.ynet.gene.data.DataField;
import com.ynet.gene.data.IndexedCollection;
import com.ynet.gene.data.InvalidArgumentException;
import com.ynet.gene.data.KeyedCollection;
import com.ynet.gene.data.ObjectNotFoundException;
import com.ynet.gene.log.GENELog;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.LifeDBLobUtil;
import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import java.io.UnsupportedEncodingException;
import java.sql.Connection;
import java.sql.SQLException;
import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;

/* loaded from: com_ynet_life_log.jar:com/ynet/life/log/LogAccessController.class */
public class LogAccessController extends GENEAccessController {
    private Map logConfigMap = null;
    public static final String FIELD_DATAGATHER = "__DATAGATHER";
    public static final String FIELD_DATA_BEFORE_CHANGE = "__DATABEFORECHANGE";
    private static final int MAX_ERROR_MESSAGE_LENGTH = 100;
    private String systemType;

    public String getSystemType() {
        return this.systemType;
    }

    public void setSystemType(String systemType) {
        this.systemType = systemType;
    }

    public void beginAccess(Object obj) {
    }

    public Object checkAccess(Context context, Object requestObject, String accessItemId) throws GENEException {
        DataGather dataGather = (DataGather) this.logConfigMap.get(accessItemId);
        if (dataGather == null) {
            GENELog.log(GENEConstance.GENE_FLOW, GENELog.INFO, 0, "没有为" + accessItemId + "配置审记日志");
            return null;
        }
        DataElement dataBeforeChange = dataGather.getDataBeforeChange(context);
        if (context.containsKey(FIELD_DATA_BEFORE_CHANGE)) {
            context.setDataValue(FIELD_DATA_BEFORE_CHANGE, dataBeforeChange);
        } else {
            context.addDataField(FIELD_DATA_BEFORE_CHANGE, dataBeforeChange);
        }
        if (context.containsKey(FIELD_DATAGATHER)) {
            context.setDataValue(FIELD_DATAGATHER, dataGather);
        } else {
            context.addDataField(FIELD_DATAGATHER, dataGather);
        }
        return context;
    }

    public void endAccess(Object obj, long beginTimeStamp) {
        super.endAccess(obj, beginTimeStamp);
        Context context = (Context) obj;
        String dealFlag = "";
        try {
            dealFlag = (String) context.getDataValue("dealFlag");
        } catch (InvalidArgumentException unused) {
            Trace.logDebug("EBCB", "由于工作日延迟，不需处理");
        } catch (ObjectNotFoundException unused2) {
            Trace.logDebug("EBCB", "由于工作日延迟，不需处理");
        }
        if ("11".equals(dealFlag) || "12".equals(dealFlag) || "13".equals(dealFlag) || "14".equals(dealFlag) || "31".equals(dealFlag) || "32".equals(dealFlag) || "33".equals(dealFlag) || "34".equals(dealFlag)) {
            return;
        }
        DataGather dataGather = (DataGather) context.get(FIELD_DATAGATHER);
        IndexedCollection indexedCollection = (DataElement) context.get(FIELD_DATA_BEFORE_CHANGE);
        IndexedCollection dataAfterChange = dataGather.getDataAfterChange(context);
        if ("iColl".equals(dataGather.getDataType()) && "single".equals(dataGather.getIcollQueryType())) {
            if (indexedCollection == null || dataAfterChange == null) {
                if (indexedCollection == null && dataAfterChange == null) {
                    standDealDataField(context, dataGather, null, null);
                } else if (indexedCollection == null) {
                    IndexedCollection iColl = dataAfterChange;
                    for (int i = 0; i < iColl.size(); i++) {
                        KeyedCollection kcoll = (KeyedCollection) iColl.get(i);
                        standDealDataField(context, dataGather, null, kcoll);
                    }
                } else {
                    IndexedCollection iColl2 = indexedCollection;
                    for (int i2 = 0; i2 < iColl2.size(); i2++) {
                        KeyedCollection kcoll2 = (KeyedCollection) iColl2.get(i2);
                        standDealDataField(context, dataGather, kcoll2, null);
                    }
                }
            } else {
                HashMap descMap = getDesc(dataGather.getLoafDesc());
                Map mapBeforeChange = convertToMap(indexedCollection, (String) descMap.get(dataGather.getPrimaryKey()));
                Map mapAfterChange = convertToMap(dataAfterChange, (String) descMap.get(dataGather.getPrimaryKey()));
                for (Map.Entry entry : mapBeforeChange.entrySet()) {
                    KeyedCollection kCollBeforeChange = (KeyedCollection) entry.getValue();
                    String primaryValue = (String) entry.getKey();
                    KeyedCollection kCollAfterChange = (KeyedCollection) mapAfterChange.get(primaryValue);
                    if (kCollBeforeChange == null || kCollAfterChange == null) {
                        standDealDataField(context, dataGather, null, null);
                        if (kCollBeforeChange == null) {
                            standDealDataField(context, dataGather, null, kCollAfterChange);
                        } else {
                            standDealDataField(context, dataGather, kCollBeforeChange, null);
                        }
                    } else {
                        standDealDataField(context, dataGather, kCollBeforeChange, kCollAfterChange);
                    }
                }
            }
        } else {
            standDealDataField(context, dataGather, indexedCollection, dataAfterChange);
        }
        context.removeDataElement(FIELD_DATAGATHER);
        context.removeDataElement(FIELD_DATA_BEFORE_CHANGE);
    }

    public void standDealDataField(Context context, DataGather dataGather, DataElement dataBeforeChange, DataElement dataAfterChange) {
        String userId = "";
        try {
            userId = (String) context.getDataValue(dataGather.getUserIdField());
        } catch (InvalidArgumentException unused) {
        } catch (ObjectNotFoundException unused2) {
        }
        String customerId = "";
        try {
            customerId = (String) context.getDataValue(dataGather.getOrgidField());
        } catch (InvalidArgumentException unused3) {
        } catch (ObjectNotFoundException unused4) {
        }
        String nowDate = LifeStandard.getServerTime("yyyyMMddHHmmss");
        String functionId = "";
        try {
            if (dataGather.getBsnCodeField() == null) {
                functionId = (String) context.getDataValue("currentBusinessCode");
            } else {
                functionId = (String) context.getDataValue(dataGather.getBsnCodeField());
            }
        } catch (InvalidArgumentException unused5) {
        } catch (ObjectNotFoundException unused6) {
        }
        String opType = "";
        try {
            if (dataGather.getOpTypeField() != null) {
                opType = (String) context.getDataValue(dataGather.getOpTypeField());
            } else {
                opType = "4";
            }
        } catch (InvalidArgumentException unused7) {
        } catch (ObjectNotFoundException unused8) {
        }
        String flowNo = "";
        try {
            if (dataGather.getFlowNoField() != null) {
                flowNo = (String) context.getDataValue(dataGather.getFlowNoField());
            }
        } catch (InvalidArgumentException unused9) {
        } catch (ObjectNotFoundException unused10) {
        }
        HashMap descMap = null;
        if (dataGather.getLoafDesc() != null) {
            descMap = getDesc(dataGather.getLoafDesc());
        }
        if ("iColl".equals(dataGather.getDataType()) && "single".equals(dataGather.getIcollQueryType())) {
            flowNo = getFlowNo((KeyedCollection) dataBeforeChange, (KeyedCollection) dataAfterChange, (String) descMap.get(dataGather.getPrimaryKey()));
        }
        String wrongCode = "";
        try {
            GENEException e = (GENEException) context.getDataValue(GENEConstance.GENE_FLOW_EXCEPTION_FIELD);
            if (e != null) {
                wrongCode = e.getErrorCode();
            } else {
                wrongCode = (String) context.getDataValue(dataGather.getWrongCodeField());
            }
        } catch (InvalidArgumentException unused11) {
        } catch (ObjectNotFoundException unused12) {
        }
        String wrongContent = "";
        try {
            GENEException e2 = (GENEException) context.getDataValue(GENEConstance.GENE_FLOW_EXCEPTION_FIELD);
            if (e2 != null) {
                wrongContent = e2.getMessage();
            } else if (dataGather.getWrongCotentField() != null && !"".equals(dataGather.getWrongCotentField())) {
                wrongContent = (String) context.getDataValue(dataGather.getWrongCotentField());
            }
        } catch (InvalidArgumentException unused13) {
        } catch (ObjectNotFoundException unused14) {
        }
        String userIdBy = "";
        if (dataGather.getUserIdBy() != null) {
            try {
                userIdBy = (String) context.getDataValue(dataGather.getUserIdBy());
            } catch (InvalidArgumentException unused15) {
            } catch (ObjectNotFoundException unused16) {
            }
        }
        String userIp = "";
        try {
            userIp = (String) context.getDataValue("session_userRemoteIP");
        } catch (InvalidArgumentException unused17) {
        } catch (ObjectNotFoundException unused18) {
        }
        String logType = dataGather.getLogType();
        String logLevel = dataGather.getLogLevel();
        String isPermission = dataGather.getDealResultField();
        String permissionToDatabase = "";
        if (isPermission != null) {
            try {
                permissionToDatabase = (String) context.getDataValue(isPermission);
            } catch (InvalidArgumentException unused19) {
            } catch (ObjectNotFoundException unused20) {
            }
        }
        StringBuffer strBuff = new StringBuffer();
        try {
            getComparedData(dataGather, dataBeforeChange, dataAfterChange, strBuff);
        } catch (Exception e3) {
            GENELog.log(GENEConstance.GENE_FLOW, GENELog.ERROR, 0, "获取日志数据错误", e3);
        }
        String str = strBuff.toString();
        String keyContent = getKeyContent(dataBeforeChange, dataAfterChange);
        String beforChangeTodataBase = "";
        if (dataBeforeChange != null) {
            if (dataBeforeChange instanceof KeyedCollection) {
                beforChangeTodataBase = getKcollStr((KeyedCollection) dataBeforeChange, descMap);
            }
            if (dataBeforeChange instanceof IndexedCollection) {
                beforChangeTodataBase = getIcollStr((IndexedCollection) dataAfterChange, descMap);
            }
        }
        String afterChangeTodataBase = "";
        if (dataAfterChange != null) {
            HashMap descMap2 = getDesc(dataGather.getLoafDesc());
            if (dataAfterChange instanceof KeyedCollection) {
                afterChangeTodataBase = getKcollStr((KeyedCollection) dataAfterChange, descMap2);
            }
            if (dataAfterChange instanceof IndexedCollection) {
                afterChangeTodataBase = getIcollStr((IndexedCollection) dataAfterChange, descMap2);
            }
        }
        insertLogToDataBase(this.systemType, userId, customerId, nowDate, functionId, opType, flowNo, wrongCode, wrongContent, keyContent, str, userIdBy, userIp, logType, logLevel, permissionToDatabase, beforChangeTodataBase, afterChangeTodataBase);
    }

    public String getFlowNo(KeyedCollection dataBeforeChange, KeyedCollection dataAfterChange, String primaryKey) {
        String flowNo = "";
        if (dataBeforeChange != null) {
            try {
                flowNo = (String) dataBeforeChange.getDataValue(primaryKey);
            } catch (ObjectNotFoundException unused) {
            } catch (InvalidArgumentException unused2) {
            }
            return flowNo;
        }
        if (dataAfterChange != null) {
            try {
                flowNo = (String) dataAfterChange.getDataValue(primaryKey);
            } catch (InvalidArgumentException unused3) {
            } catch (ObjectNotFoundException unused4) {
            }
            return flowNo;
        }
        return flowNo;
    }

    public String getKeyContent(DataElement dataBeforeChange, DataElement dataAfterChange) {
        DataElement keyDataElement;
        String keyContent = "";
        if (dataBeforeChange != null) {
            keyDataElement = dataBeforeChange;
        } else {
            keyDataElement = dataAfterChange;
        }
        if (keyDataElement == null) {
            return keyContent;
        }
        if (keyDataElement instanceof DataField) {
            keyContent = keyDataElement.getName();
        } else if (keyDataElement instanceof KeyedCollection) {
            Iterator it = ((KeyedCollection) keyDataElement).entrySet().iterator();
            while (it.hasNext()) {
                String fieldName = (String) ((Map.Entry) it.next()).getKey();
                if (keyContent == null || "".equals(keyContent)) {
                    keyContent = fieldName;
                } else {
                    keyContent = String.valueOf(keyContent) + "," + fieldName;
                }
            }
        } else {
            IndexedCollection iColl = (IndexedCollection) keyDataElement;
            if (iColl != null && iColl.size() > 0) {
                Iterator it2 = iColl.getElementAt(0).entrySet().iterator();
                while (it2.hasNext()) {
                    String fieldName2 = (String) ((Map.Entry) it2.next()).getKey();
                    if (keyContent == null || "".equals(keyContent)) {
                        keyContent = fieldName2;
                    } else {
                        keyContent = String.valueOf(keyContent) + "," + fieldName2;
                    }
                }
            }
        }
        return keyContent;
    }

    /* JADX WARN: Multi-variable type inference failed */
    /* JADX WARN: Type inference failed for: r0v19, types: [java.lang.String[]] */
    /* JADX WARN: Type inference failed for: r0v23 */
    /* JADX WARN: Type inference failed for: r0v24, types: [com.ynet.life.exception.TranFailException] */
    /* JADX WARN: Type inference failed for: r0v26, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v27, types: [java.sql.Connection] */
    /* JADX WARN: Type inference failed for: r0v28, types: [java.sql.SQLException] */
    /* JADX WARN: Type inference failed for: r0v32, types: [java.sql.Connection] */
    public void insertLogToDataBase(String str, String str2, String str3, String str4, String str5, String str6, String str7, String str8, String str9, String str10, String str11, String str12, String str13, String str14, String str15, String str16, String str17, String str18) {
        TranFailException tranFailException;
        TranFailException tranFailException2 = null;
        TranFailException tranFailException3 = null;
        try {
            tranFailException2 = LifeDBAccess.getConnection();
            tranFailException3 = tranFailException2;
        } catch (TranFailException e) {
            tranFailException2.printStackTrace();
        }
        String str19 = "";
        String str20 = "";
        try {
            str19 = LifeDBAccess.getSequenceNo(tranFailException3, "PUB_LOG_NO");
            str20 = str19;
        } catch (TranFailException e2) {
            str19.printStackTrace();
        }
        if (str9 != null) {
            try {
                byte[] bytes = str9.getBytes("UTF-8");
                if (bytes.length > MAX_ERROR_MESSAGE_LENGTH) {
                    byte[] bArr = new byte[MAX_ERROR_MESSAGE_LENGTH];
                    System.arraycopy(bytes, 0, bArr, 0, MAX_ERROR_MESSAGE_LENGTH);
                    str9 = new String(bArr, "UTF-8");
                }
            } catch (UnsupportedEncodingException unused) {
            }
        }
        ?? r0 = {str10, str11, str17, str18};
        try {
            try {
                r0 = tranFailException3;
                LifeDBLobUtil.insertBlob((Connection) r0, "PUB_AUDIT_LOG", "ALG_LOGID", str20, new String[]{"ALG_LOGID", "ALG_SYSID", "ALG_USERID", "ALG_ORGID", "ALG_OPTIME", "ALG_BSNCODE", "ALG_OPTYPE", "ALG_FLOWNO", "ALG_ERRORCODE", "ALG_ERRORMSG", "ALG_USERIDBY", "ALG_USERIP", "ALG_LOGTYPE", "ALG_LEVEL", "ALG_DEALTYPE"}, new String[]{str20, str, str2, str3, str4, str5, str6, str7, str8, str9, str12, str13, str14, str15, str16}, new String[]{"ALG_KEYINF", "ALG_CHANGEINF", "ALG_BEFORECHANGE", "ALG_AFTERCHANGE"}, (String[]) r0);
                try {
                    r0 = tranFailException3;
                    r0.commit();
                    tranFailException = r0;
                } catch (SQLException e3) {
                    r0.printStackTrace();
                    tranFailException = r0;
                }
                try {
                    tranFailException = tranFailException3;
                    LifeDBAccess.releaseConnection(tranFailException);
                } catch (TranFailException e4) {
                    tranFailException.printStackTrace();
                }
            } catch (Throwable th) {
                try {
                    r0 = tranFailException3;
                    LifeDBAccess.releaseConnection((Connection) r0);
                } catch (TranFailException e5) {
                    r0.printStackTrace();
                }
                throw th;
            }
        } catch (TranFailException e6) {
            try {
                tranFailException3.rollback();
            } catch (SQLException unused2) {
            }
            e6.printStackTrace();
            TranFailException tranFailException4 = tranFailException3;
            try {
                LifeDBAccess.releaseConnection(tranFailException4);
            } catch (TranFailException e7) {
                tranFailException4.printStackTrace();
            }
        }
    }

    public void addDataGather(DataGather dataGather) {
        if (this.logConfigMap == null) {
            this.logConfigMap = new HashMap();
        }
        this.logConfigMap.put(dataGather.getFlowId(), dataGather);
    }

    public String getKcollStr(KeyedCollection kColl, HashMap loafDesc) {
        StringBuffer strBuff = new StringBuffer();
        if (kColl != null) {
            Iterator it = kColl.entrySet().iterator();
            while (it.hasNext()) {
                DataField fieldBefore = (DataField) ((Map.Entry) it.next()).getValue();
                String fieldName = fieldBefore.getName();
                String fieldValue = (String) fieldBefore.getValue();
                strBuff.append(fieldName);
                strBuff.append(":");
                strBuff.append(fieldValue);
                strBuff.append("\n");
            }
        }
        return strBuff.toString();
    }

    public String getIcollStr(IndexedCollection icoll, HashMap loafDesc) {
        StringBuffer strBuff = new StringBuffer();
        if (icoll != null && icoll.size() > 0) {
            for (int i = 0; i < icoll.size(); i++) {
                KeyedCollection kColl = icoll.getElementAt(i);
                if (kColl != null) {
                    Iterator it = kColl.entrySet().iterator();
                    while (it.hasNext()) {
                        DataField fieldBefore = (DataField) ((Map.Entry) it.next()).getValue();
                        String fieldName = fieldBefore.getName();
                        String fieldValue = (String) fieldBefore.getValue();
                        strBuff.append(fieldName);
                        strBuff.append(":");
                        strBuff.append(fieldValue);
                        strBuff.append("\n");
                    }
                }
            }
        }
        return strBuff.toString();
    }

    private void getComparedData(DataGather dataGather, DataElement dataBeforeChange, DataElement dataAfterChange, StringBuffer strBuff) throws TranFailException, InvalidArgumentException {
        if ("0".equals(dataGather.getLogType())) {
            return;
        }
        HashMap descMap = new HashMap();
        String[] desc = dataGather.getLoafDesc().split("\\|");
        for (int i = 0; i < desc.length; i++) {
            descMap.put(desc[i].split("=")[0], desc[i].split("=")[1]);
        }
        if (dataBeforeChange == null && dataAfterChange == null) {
            return;
        }
        if ((dataBeforeChange instanceof DataField) || (dataAfterChange instanceof DataField)) {
            if (!(dataAfterChange instanceof DataField)) {
                throw new TranFailException("EBLN0000", "为" + dataGather.getFlowId() + "配置的修改前修改后的数据类型不一致，无法比较");
            }
            if (dataBeforeChange == null) {
                DataField fieldAfter = (DataField) dataAfterChange;
                String fieldName = fieldAfter.getName();
                String valueAfter = (String) fieldAfter.getValue();
                strBuff.append(fieldName);
                strBuff.append(":");
                strBuff.append(valueAfter);
                strBuff.append("\n");
                return;
            }
            if (dataAfterChange == null) {
                DataField fieldBefore = (DataField) dataBeforeChange;
                String fieldName2 = fieldBefore.getName();
                String valueBefore = (String) fieldBefore.getValue();
                strBuff.append(fieldName2);
                strBuff.append(":");
                strBuff.append("修改前值为 ");
                strBuff.append(valueBefore);
                strBuff.append("\t修改后值为 ");
                strBuff.append("删除\n");
                return;
            }
            DataField fieldBefore2 = (DataField) dataBeforeChange;
            String fieldName3 = fieldBefore2.getName();
            String valueBefore2 = (String) fieldBefore2.getValue();
            String valueAfter2 = (String) ((DataField) dataAfterChange).getValue();
            if (valueBefore2 == null || !valueBefore2.equals(valueAfter2)) {
                if (valueBefore2 == null && valueAfter2 == null) {
                    return;
                }
                strBuff.append(fieldName3);
                strBuff.append(":");
                strBuff.append("修改前值为 ");
                strBuff.append(valueBefore2);
                strBuff.append("\t修改后值为 ");
                strBuff.append(valueAfter2);
                strBuff.append("\n");
                return;
            }
            return;
        }
        if ((dataBeforeChange instanceof KeyedCollection) || (dataAfterChange instanceof KeyedCollection)) {
            if (!(dataAfterChange instanceof KeyedCollection)) {
                throw new TranFailException("EBLN0000", "为" + dataGather.getFlowId() + "配置的修改前修改后的数据类型不一致，无法比较");
            }
            if (dataBeforeChange == null) {
                strBuff.append("【新增】\n");
                dataBeforeChange = new KeyedCollection();
            }
            if (dataAfterChange == null) {
                strBuff.append("【删除】\n");
                dataAfterChange = new KeyedCollection();
            }
            KeyedCollection kColl = (KeyedCollection) dataBeforeChange;
            KeyedCollection kCollAfter = (KeyedCollection) dataAfterChange;
            KeyedCollection kCollAfter1 = (KeyedCollection) kCollAfter.clone();
            for (Map.Entry entry : kColl.entrySet()) {
                DataElement fieldBefore3 = (DataElement) entry.getValue();
                String fieldName4 = (String) entry.getKey();
                getComparedData(dataGather, fieldBefore3, kCollAfter.getDataElement(fieldName4), strBuff);
                kCollAfter1.remove(fieldName4);
            }
            if (!kCollAfter1.isEmpty()) {
                Iterator it = kCollAfter1.entrySet().iterator();
                while (it.hasNext()) {
                    getComparedData(dataGather, null, (DataElement) ((Map.Entry) it.next()).getValue(), strBuff);
                }
                return;
            }
            return;
        }
        if ((dataBeforeChange instanceof IndexedCollection) || (dataAfterChange instanceof IndexedCollection)) {
            if (!(dataAfterChange instanceof IndexedCollection)) {
                throw new TranFailException("EBLN0000", "为" + dataGather.getFlowId() + "配置的修改前修改后的数据类型不一致，无法比较");
            }
            strBuff.append("【列表】\n");
            Map mapBeforeChange = convertToMap((IndexedCollection) dataBeforeChange, (String) descMap.get(dataGather.getPrimaryKey()));
            Map mapAfterChange = convertToMap((IndexedCollection) dataAfterChange, (String) descMap.get(dataGather.getPrimaryKey()));
            Map mapAfterChange1 = (Map) ((HashMap) mapAfterChange).clone();
            int index = 0;
            for (Map.Entry entry2 : mapBeforeChange.entrySet()) {
                index++;
                KeyedCollection kCollBeforeChange = (KeyedCollection) entry2.getValue();
                String primaryValue = (String) entry2.getKey();
                KeyedCollection kCollAfterChange = (KeyedCollection) mapAfterChange.get(primaryValue);
                if (kCollAfterChange == null) {
                    strBuff.append("记录" + index + "：删除\n");
                } else {
                    strBuff.append("记录" + index + "：修改\n");
                }
                getComparedData(dataGather, kCollBeforeChange, kCollAfterChange, strBuff);
                mapAfterChange1.remove(primaryValue);
            }
            if (!mapAfterChange1.isEmpty()) {
                Iterator it2 = mapAfterChange1.entrySet().iterator();
                while (it2.hasNext()) {
                    index++;
                    strBuff.append("记录" + index + "：新增\n");
                    KeyedCollection kColl2 = (KeyedCollection) ((Map.Entry) it2.next()).getValue();
                    getComparedData(dataGather, null, kColl2, strBuff);
                }
            }
        }
    }

    private Map convertToMap(IndexedCollection iColl, String primaryKey) {
        Map map = new HashMap();
        if (iColl != null) {
            int length = iColl.size();
            for (int i = 0; i < length; i++) {
                KeyedCollection kColl = iColl.getElementAt(i);
                String mapKey = (String) kColl.get(primaryKey);
                map.put(mapKey, kColl);
            }
        }
        return map;
    }

    public HashMap getDesc(String loafDesc) {
        HashMap descMap = new HashMap();
        String[] desc = loafDesc.split("\\|");
        for (int i = 0; i < desc.length; i++) {
            descMap.put(desc[i].split("=")[0], desc[i].split("=")[1]);
        }
        return descMap;
    }
}
